==> babel-preset-everything-0.0.1.tgz: package/README.md <==
# babel-preset-everything

[![GitHub stars](https://img.shields.io/github/stars/codejamninja/babel-preset-everything.svg?style=social&label=Stars)](https://github.com/codejamninja/babel-preset-everything)

> all official proposed plugins for babel 7

Please ★ this repo if you found it useful ★ ★ ★


## Features

* @babel/plugin-proposal-object-rest-spread


## Installation

```sh
npm install --save-dev babel-preset-everything
```


## Dependencies

* [NodeJS](https://nodejs.org)
* [Babel 7](https://babeljs.io)


## Usage

[Contribute](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md) usage docs


## Support

Submit an [issue](https://github.com/codejamninja/babel-preset-everything/issues/new)


## Screenshots

[Contribute](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md) a screenshot


## Contributing

Review the [guidelines for contributing](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md)


## License

[MIT License](https://github.com/codejamninja/babel-preset-everything/blob/master/LICENSE)

[Jam Risser](https://codejam.ninja) © 2018


## Changelog

Review the [changelog](https://github.com/codejamninja/babel-preset-everything/blob/master/CHANGELOG.md)


## Credits

* [Jam Risser](https://codejam.ninja) - Author


## Support on Liberapay

A ridiculous amount of coffee ☕ ☕ ☕ was consumed in the process of building this project.

[Add some fuel](https://liberapay.com/codejamninja/donate) if you'd like to keep me going!

[![Liberapay receiving](https://img.shields.io/liberapay/receives/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)

==> babel-preset-everything-0.2.2.tgz: package/README.md <==
# babel-preset-everything

[![GitHub stars](https://img.shields.io/github/stars/codejamninja/babel-preset-everything.svg?style=social&label=Stars)](https://github.com/codejamninja/babel-preset-everything)

> all official proposed plugins for babel 7

Please ★ this repo if you found it useful ★ ★ ★


## Features

* @babel/plugin-proposal-class-properties
* @babel/plugin-proposal-decorators
* @babel/plugin-proposal-export-default-from
* @babel/plugin-proposal-export-namespace-from
* @babel/plugin-proposal-function-bind
* @babel/plugin-proposal-function-sent
* @babel/plugin-proposal-json-strings
* @babel/plugin-proposal-logical-assignment-operators
* @babel/plugin-proposal-nullish-coalescing-operator
* @babel/plugin-proposal-numeric-separator
* @babel/plugin-proposal-optional-chaining
* @babel/plugin-proposal-pipeline-operator
* @babel/plugin-proposal-throw-expressions
* @babel/plugin-syntax-dynamic-import
* @babel/plugin-syntax-import-meta


## Installation

```sh
npm install --save-dev babel-preset-everything
```


## Dependencies

* [NodeJS](https://nodejs.org)
* [Babel 7](https://babeljs.io)


## Usage

[Contribute](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md) usage docs


## Support

Submit an [issue](https://github.com/codejamninja/babel-preset-everything/issues/new)


## Screenshots

[Contribute](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md) a screenshot


## Contributing

Review the [guidelines for contributing](https://github.com/codejamninja/babel-preset-everything/blob/master/CONTRIBUTING.md)


## License

[MIT License](https://github.com/codejamninja/babel-preset-everything/blob/master/LICENSE)

[Jam Risser](https://codejam.ninja) © 2018


## Changelog

Review the [changelog](https://github.com/codejamninja/babel-preset-everything/blob/master/CHANGELOG.md)


## Credits

* [Jam Risser](https://codejam.ninja) - Author


## Support on Liberapay

A ridiculous amount of coffee ☕ ☕ ☕ was consumed in the process of building this project.

[Add some fuel](https://liberapay.com/codejamninja/donate) if you'd like to keep me going!

[![Liberapay receiving](https://img.shields.io/liberapay/receives/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
[![Liberapay patrons](https://img.shields.io/liberapay/patrons/codejamninja.svg?style=flat-square)](https://liberapay.com/codejamninja/donate)
